
.. image:: http://genomicsandhealth.org/files/logo_ga.png

==============================
GA4GH Reference Implementation
==============================

This is an early alpha of the GA4GH reference client
and server applications.
It is under heavy development, and many aspects of
the layout and APIs will change as requirements are better understood.
If you would like to help, please check out our list of
`issues <https://github.com/ga4gh/server/issues>`_!

Full documentation is available at `read-the-docs.org
<http://ga4gh-reference-implementation.readthedocs.org/>`_.

- For a quick start with the GA4GH API, please see our
  `demo <http://ga4gh-reference-implementation.readthedocs.org/en/stable/demo.html>`_.
- To configure and deploy the GA4GH server in production
  please see the
  `installation
  <http://ga4gh-reference-implementation.readthedocs.org/en/stable/installation.html>`_
  page.
- If you would like to contribute to the project, please see the
  `development
  <http://ga4gh-reference-implementation.readthedocs.org/en/stable/development.html>`_
  page.
